try:
    from ._version import version as __version__
except ImportError:
    __version__ = "unknown"

## import required functions
import os
# ignore gpu: this needs to rectfied incase there is gpu access to tensorflow
os.environ["CUDA_VISIBLE_DEVICES"]="-1" 
from napari_plugin_engine import napari_hook_implementation
from magicgui import magic_factory
from skimage.transform import rescale,resize
from skimage.feature import shape_index
import numpy as np
from skimage.util import random_noise

# import MiSiC Stuff
from misic.misic import *
from misic.extras import *
from misic.utils import *

# get helper functions
from misic_ui.misic_helpers import *

# make misic
misic = MiSiC()

# make default params dictionary
params = {}
params['scale'] = 1.0
params['invert'] = False
params['sensitivity'] = 0.3
params['local_noise'] = True
params['post_process'] = True
params['misic'] = misic

## MagicGui widget for single image segmentation
@magic_factory(auto_call=True,
scale = {"widget_type": "FloatSlider", "max": 2.10,"min": 0.50,"step":0.1},
sensitivity = {"widget_type": "FloatSlider", "max": 2.00,"min": 0.00,"step":0.0005})
def segment(data: 'napari.types.ImageData', 
frame_num = 0,
invert=True, 
scale = 1.0, 
local_noise = True,
sensitivity = 0.1, 
post_process= False,
) -> 'napari.types.LabelsData':
    scale = min(scale,2.5)
    params['scale'] = scale
    params['invert'] = invert
    params['sensitivity'] = sensitivity
    params['local_noise'] = local_noise
    params['post_process'] = post_process
    
    if len(data.shape) >2:
        frame_num = min(frame_num,len(data))
        im = np.copy(data[frame_num])
    else:
        im = np.copy(data)

    #status = 'MiSiC: processing ...'
    yp = process(im,params)
    #status = 'MiSiC'
    return yp

# once the parameters are the selected for single image, then process the stack
def segment_stack(data: "napari.types.ImageData") -> "napari.types.LabelsData":
    params['scale'] = min(params['scale'],2.5)
    
    if len(data.shape) <3:
        im = np.copy(data)
        yp = process(im,params)
    else:
        im = np.copy(data)
        yp = process_all(im,params)
    return yp


# napari hooks

@napari_hook_implementation
def napari_experimental_provide_dock_widget():
    return segment

@napari_hook_implementation
def napari_experimental_provide_function():
    # we can return a single function
    # or a tuple of (function, magicgui_options)
    # or a list of multiple functions with or without options, as shown here:
    return segment_stack

