import numpy as np
from misic.misic import *
from misic.extras import *
from misic.utils import *
def shape_data(data):
    size = data.shape
    N = len(size)
    # single image single channel
    if N ==2:
        # single frames
        return data[np.newaxis,:,:]

    return data 

def process(data, params):
    im = np.copy(data)
    scale = params['scale']
    invert = params['invert']
    sensitivity = params['sensitivity']
    local_noise = params['local_noise']
    post_process = params['post_process']
    misic = params['misic']

    im = im if scale==1 else rescale(im,scale,preserve_range=True)
    im = (1.0 - normalize2max(im)) if invert else im
    im = add_noise(im,sensitivity) if local_noise else random_noise(im,mode = 'gaussian',var = sensitivity)
    yp = misic.segment(im,invert = False)
    yp = yp if scale==1 else resize(yp,[data.shape[0],data.shape[1]])
    yp = postprocess_ws(data,yp) if post_process else ((yp[:,:,0]>0.65)*255.0).astype(np.uint8)
    return yp

def process_all(data, params):
    imgs = np.copy(data)
    scale = params['scale']
    invert = params['invert']
    sensitivity = params['sensitivity']
    local_noise = params['local_noise']
    post_process = params['post_process']
    misic = params['misic']
    
    y_predicted = []
    for ii,im in enumerate(imgs):
        im = im if scale==1 else rescale(im,scale,preserve_range=True)
        im = (1.0 - normalize2max(im)) if invert else im
        im = add_noise(im,sensitivity) if local_noise else random_noise(im,mode = 'gaussian',var = sensitivity)
        yp = misic.segment(im,invert = False)
        yp = yp if scale==1 else resize(yp,[data.shape[0],data.shape[1],1])
        yp = postprocess_ws(data[ii],yp) if post_process else ((yp[:,:,0]>0.65)*255.0).astype(np.uint8)
        y_predicted.append(yp)
    return np.array(y_predicted)